EchoTestConfig class

Constructors

EchoTestConfig({required String userId, required String roomId, required String token, required bool enableAudio, required bool enableVideo, required int audioReportInterval})

Properties

audioReportInterval int
getter/setter pair
enableAudio bool
getter/setter pair
enableVideo bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
roomId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
getter/setter pair
userId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited