ProblemFeedbackOption enum

@brief 音视频质量反馈问题类型

Inheritance
Available extensions

Values

none → const ProblemFeedbackOption

@brief 没有问题

other_message → const ProblemFeedbackOption

@brief 其他问题

disconnected → const ProblemFeedbackOption

@brief 连接失败

ear_back_delay → const ProblemFeedbackOption

@brief 耳返延迟大

local_noise → const ProblemFeedbackOption

@brief 本端有杂音

local_audio_lagging → const ProblemFeedbackOption

@brief 本端声音卡顿

local_no_audio → const ProblemFeedbackOption

@brief 本端无声音

local_audio_strength → const ProblemFeedbackOption

@brief 本端声音大/小

local_echo → const ProblemFeedbackOption

@brief 本端有回声

local_video_fuzzy → const ProblemFeedbackOption

@brief 本端视频模糊

local_not_sync → const ProblemFeedbackOption

@brief 本端音视频不同步

local_video_lagging → const ProblemFeedbackOption

@brief 本端视频卡顿

local_no_video → const ProblemFeedbackOption

@brief 本端无画面

remote_noise → const ProblemFeedbackOption

@brief 远端有杂音

remote_audio_lagging → const ProblemFeedbackOption

@brief 远端声音卡顿

remote_no_audio → const ProblemFeedbackOption

@brief 远端无声音

remote_audio_strength → const ProblemFeedbackOption

@brief 远端声音大/小

remote_echo → const ProblemFeedbackOption

@brief 远端有回声

remote_video_fuzzy → const ProblemFeedbackOption

@brief 远端视频模糊

remote_not_sync → const ProblemFeedbackOption

@brief 远端音视频不同步

remote_video_lagging → const ProblemFeedbackOption

@brief 远端视频卡顿

remote_no_video → const ProblemFeedbackOption

@brief 远端无画面

Properties

$value → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ProblemFeedbackOption>
A constant List of the values in this enum, in order of their declaration.