MixedStreamSpatialAudioConfig class

@brief 空间音频配置

Constructors

MixedStreamSpatialAudioConfig({bool enableSpatialRender = false, Position? audienceSpatialPosition, HumanOrientation? audienceSpatialOrientation})
MixedStreamSpatialAudioConfig.disabled()

Properties

audienceSpatialOrientation → HumanOrientation?
@brief 观众空间音频方向
final
audienceSpatialPosition → Position?
@brief 观众空间音频位置
final
enableSpatialRender → bool
@brief 是否启用空间音频
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited