RTCSurfaceView class

@brief 视频渲染设置。

若使用 Flutter 3.0.0 及以上版本开发 Android 应用,建议使用 Android 6.0 及以上设备,否则会出现图层显示错误。

不同平台对应不同对象:

Inheritance

Constructors

RTCSurfaceView({Key? key, required RTCViewContext context, VideoRenderMode renderMode = VideoRenderMode.fit, VideoRotation renderRotation = VideoRotation.rotation0, int backgroundColor = 0, bool zOrderOnTop = false, bool zOrderMediaOverlay = false, PlatformViewCreatedCallback? onPlatformViewCreated, Set<Factory<OneSequenceGestureRecognizer>>? gestureRecognizers})
const

Properties

backgroundColor int
@brief 用于填充画布空白部分的背景颜色
final
context RTCViewContext
@brief 传入 context 用于实例初始化
final
gestureRecognizers Set<Factory<OneSequenceGestureRecognizer>>?
@brief 应将哪些手势传给 PlatformView
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPlatformViewCreated PlatformViewCreatedCallback?
@brief PlatformView 被创建时,收到此回调
final
renderMode VideoRenderMode
@brief 视频渲染模式
final
renderRotation VideoRotation
@brief 视频旋转角度
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zOrderMediaOverlay bool
@brief 设置 SurfaceView 的 Surface 是否放置在另一个常规 SurfaceView 的顶部。
final
zOrderOnTop bool
@brief 设置 SurfaceView 的 Surface 是否放置在本身所在窗口的最顶部。
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited