RTCViewContext class

@brief 用于 RTCSurfaceView 初始化

Constructors

RTCViewContext.echoTestContext()
RTCViewContext.localContext({required String userId, StreamIndex streamIndex = StreamIndex.main, VideoRotation videoRotation = VideoRotation.rotation0})
设置渲染本地视频的画布
RTCViewContext.publicStreamContext(String publicStreamId)
@brief 设置渲染 WTN 公共流视频的画布
RTCViewContext.remoteContext({required String roomId, required String userId, StreamIndex streamIndex = StreamIndex.main, VideoRotation videoRotation = VideoRotation.rotation0, String? streamId = ''})
@brief 设置渲染远端视频的画布

Properties

canvasType VideoCanvasType
@brief 画布类型
final
hasAudio bool
@brief 是否有音频
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasVideo bool
@brief 是否有视频
getter/setter pair
publicStreamId String?
@brief 公共流 ID
getter/setter pair
roomId String
@brief 需要被渲染的用户所在的房间 ID
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId String?
@brief 流 ID
getter/setter pair
streamIndex StreamIndex
@brief 流类型
final
userId String
@brief 需要被渲染的用户的 ID
final
videoRotation VideoRotation
@brief 视频旋转角度
final
viewId String?
@brief View ID
getter/setter pair
viewType String
@brief View 类型
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited