RemoteSnapshot class
@brief 远端截图
Constructors
- RemoteSnapshot({int taskId = 0, required String streamId, required StreamInfo streamInfo, required String filePath, int width = 0, int height = 0})
Properties
- filePath → String
-
@brief 截图结果文件路径
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
@brief 图片高度
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamId → String
-
@brief 远端流 ID
final
- streamInfo → StreamInfo
-
@brief 流信息
final
- taskId ↔ int
-
@brief 截图任务 ID
getter/setter pair
- width ↔ int
-
@brief 图片宽度
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited