Watermark class

@brief 水印图片相对视频流的位置和大小。

Inheritance

Constructors

Watermark({required float x, required float y, required float width, required float height})
Watermark.none()

Properties

$instance → dynamic
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
height float
@brief 水印图片高度与视频流高度的比值,取值范围为 [0,1)。
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width float
@brief 水印图片宽度与视频流宽度的比值,取值范围 [0,1)。
getter/setter pairinherited
x float
@brief 水印图片相对视频流左上角的横向偏移与视频流宽度的比值,取值范围为 [0,1)。
getter/setter pairinherited
y float
@brief 水印图片相对视频流左上角的纵向偏移与视频流高度的比值,取值范围为 [0,1)。
getter/setter pairinherited

Methods

$createInstance(List args) → dynamic
Factory method for creating instances
inherited
$destroy() → void
inherited
$init(List args) → void
inherited
findOverrideIndices(List args, List<List<int>> indicesList) List<int>
查找重载参数下标列表 @desc android 构造函数存在重载 此方法通过实际传入参数与构造函数参数列表集合的比对,来获取当前实际的需要使用的参数列表
inherited
fn2AndroidClass(Function callback, dynamic nativeClass(), String methodName) → dynamic
与 ts runtime 中的 fn2AndroidClass 功能一致 将 Dart 函数转换为 Android 回调类实例供 Android 侧使用
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited
transformToPlatformConstructorArgs(List args, List<int> indices, Map<String, dynamic> typeMap, Map<String, dynamic> enumMap, Map<String, dynamic> classMap, String platformVar) List
实例化参数处理 将 pack 过后的 enum / class 转成 android / ios 平台侧的 enum / class
inherited
updateInstance(dynamic instance) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited