ByteRTCMediaMetadataObserver class

Inheritance
  • Object
  • NativeClass
  • NativeObserverClass
  • ByteRTCMediaMetadataObserver

Constructors

ByteRTCMediaMetadataObserver([NativeClassOptions? options])

Properties

$instance ↔ dynamic
getter/setter pairinherited
$resource → NativeResource
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ready Future<void>
Whether the instance is initialized
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
emit(String name, List args) → dynamic
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receiveVideoFrameFromUID$withExtendedData$atTimestamp(NSString uid, NSData extendedData, NSTimeInterval timestamp) FutureOr<void>
@detail callback @author wangjunlin.3182 @brief 当 SDK 收到的视频帧包含 medatada 时,会回调该接口 @param uid 当前帧所属的用户 ID @param extendedData metadata @param timestamp 包含 metadata 视频帧的时间戳,单位为微秒 @note 回调中不能做长时间逻辑处理,以免影响视频卡顿
registerEvent(String name, dynamic method) → void
inherited
sendInstanceGet<T>(String property) Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) Future<void>
Set instance property
inherited
toString() String
A string representation of this object.
inherited
updateInstance(dynamic instance) → void
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited