ByteRTCMediaPlayerAudioFrameObserver class

Inheritance
  • Object
  • NativeClass
  • NativeObserverClass
  • ByteRTCMediaPlayerAudioFrameObserver
Implementers

Constructors

ByteRTCMediaPlayerAudioFrameObserver([NativeClassOptions? options])

Properties

$instance ↔ dynamic
getter/setter pairinherited
$resource → NativeResource
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
emit(String name, List args) → dynamic
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFrame$audioFrame(int playerId, ByteRTCAudioFrame audioFrame) → FutureOr<void>
@detail callback @brief 当本地音频文件混音时,回调播放的音频帧。 @param playerId 播放器 ID @param audioFrame 参看 ByteRTCAudioFrame{@link #ByteRTCAudioFrame}。
registerEvent(String name, dynamic method) → void
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateInstance(dynamic instance) → void
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited