AVSyncEvent enum
{zh} * @detail keytype @brief AVSync 事件类型
Values
- invalid_uid_repeated → const AVSyncEvent
-
@brief 音视频同步失败。
当前音频源已与其他视频源关联同步关系。
单个音频源不支持与多个视频源同时同步。
Properties
- $value → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AVSyncEvent> - A constant List of the values in this enum, in order of their declaration.