PublishStateChangeReason enum

{zh} * @detail keytype @brief 发布状态变化原因

Inheritance
Available extensions

Values

publish → const PublishStateChangeReason

@brief 用户调用发布

unpublish → const PublishStateChangeReason

@brief 用户取消发布

no_publish_permission → const PublishStateChangeReason

@brief 发布 token 没有权限

over_stream_publish_limit → const PublishStateChangeReason

@brief 发布流总数超过上限

multiroom_unpublish_failed → const PublishStateChangeReason

@brief 将一路流发布到多个房间时,其中一个房间取消发布失败。

publish_stream_failed → const PublishStateChangeReason

@brief 服务器错误导致发布失败

publish_stream_forbiden → const PublishStateChangeReason

@brief 观众尝试发布操作

user_in_publish → const PublishStateChangeReason

@brief 用户已经在其他房间发布过流,或者用户正在发布。

stream_publish_by_other → const PublishStateChangeReason

@brief 用户已经在其他房间发布过流,或者用户正在发布。

stream_id_invalid → const PublishStateChangeReason

@brief 流 ID 无效

Properties

$value → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PublishStateChangeReason>
A constant List of the values in this enum, in order of their declaration.