SubscribeStateChangeReason enum

{zh} * @detail keytype @brief 订阅状态变化原因

Inheritance
Available extensions

Values

subscribe → const SubscribeStateChangeReason

@brief 本端调用订阅

unsubscribe → const SubscribeStateChangeReason

@brief 本端取消订阅

remote_publish → const SubscribeStateChangeReason

@brief 远端发布流

remote_unpublish → const SubscribeStateChangeReason

@brief 远端取消发布流

stream_failed_5_xx → const SubscribeStateChangeReason

@brief 由于服务器错误导致订阅失败。SDK 会自动重试订阅

stream_failed_404 → const SubscribeStateChangeReason

@brief 当前房间中找不到订阅的音视频流导致订阅失败。SDK 会自动重试订阅,若仍订阅失败则建议你退出重试。

over_stream_subscribe_limit → const SubscribeStateChangeReason

@brief 当用户订阅的音视频流总数已达上限时,继续订阅更多流时会失败,同时用户会收到此错误通知。

no_subscribe_permission → const SubscribeStateChangeReason

@brief 用户订阅所在房间中的音视频流失败,失败原因为用户没有订阅流的权限。

Properties

$value → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubscribeStateChangeReason>
A constant List of the values in this enum, in order of their declaration.