VirtualBackgroundSource class
@brief 背景贴纸对象。
- Inheritance
-
- Object
- PackClass
- VirtualBackgroundSource
- VirtualBackgroundSource
Constructors
- VirtualBackgroundSource({VirtualBackgroundSourceType sourceType = $p.VirtualBackgroundSourceType.color, int sourceColor = 0x000000, String sourcePath = ''})
- VirtualBackgroundSource.color({required int sourceColor})
- VirtualBackgroundSource.image({required String sourcePath})
Properties
- $instance → dynamic
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceColor ↔ int
-
@brief 纯色背景使用的颜色。
格式为 0xAARRGGBB 。getter/setter pairinherited - sourcePath ↔ String
-
@brief 自定义背景图片的绝对路径。
- 支持本地文件绝对路径 (file://xxx) 和 Asset 资源路径 (asset://xxx)。 - 支持的格式为 jpg、jpeg、png。 - 图片分辨率超过 1080P 时,图片会被等比缩放至和视频一致。 - 图片和视频宽高比一致时,图片会被直接缩放至和视频一致。 - 图片和视频长宽比不一致时,为保证图片内容不变形,图片按短边缩放至与视频帧一致,使图片填满视频帧,对多出的高或宽进行剪裁。 - 自定义图片带有局部透明效果时,透明部分由黑色代替。getter/setter pairinherited - sourceType ↔ VirtualBackgroundSourceType
-
@brief 虚拟背景类型,详见 VirtualBackgroundSourceType{@link #VirtualBackgroundSourceType} 。
getter/setter pairinherited
Methods
-
$createInstance(
List args) → dynamic -
Factory method for creating instances
inherited
-
$destroy(
) → void -
inherited
-
$init(
List args) → void -
inherited
-
findOverrideIndices(
List args, List< List< indicesList) → List<int> >int> -
查找重载参数下标列表
@desc android 构造函数存在重载
此方法通过实际传入参数与构造函数参数列表集合的比对,来获取当前实际的需要使用的参数列表
inherited
-
fn2AndroidClass(
Function callback, dynamic nativeClass(), String methodName) → dynamic -
与 ts runtime 中的 fn2AndroidClass 功能一致
将 Dart 函数转换为 Android 回调类实例供 Android 侧使用
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transformToPlatformConstructorArgs(
List args, List< int> indices, Map<String, dynamic> typeMap, Map<String, dynamic> enumMap, Map<String, dynamic> classMap, String platformVar) → List -
实例化参数处理
将 pack 过后的 enum / class 转成 android / ios 平台侧的 enum / class
inherited
-
updateInstance(
dynamic instance) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited