ByteRTCWarningCode enum
Values
- ByteRTCWarningCodePublishStreamFailed → const ByteRTCWarningCode
-
@brief 发布音视频流失败。通过 rtcRoom:onVideoPublishStateChanged:info:state:reason:{@link #ByteRTCRoomDelegate#rtcRoom:onVideoPublishStateChanged:info:state:reason}、rtcRoom:onAudioPublishStateChanged:info:state:reason:{@link #ByteRTCRoomDelegate#rtcRoom:onAudioPublishStateChanged:info:state:reason} 回调。
当你在所在房间中发布音视频流时,由于服务器错误导致发布失败。SDK 会自动重试发布。 - ByteRTCWarningCodeSubscribeStreamFailed404 → const ByteRTCWarningCode
-
@brief 订阅音视频流失败。通过以下回调通知: rtcRoom:onVideoSubscribeStateChanged:info:state:reason:{@link #ByteRTCRoomDelegate#rtcRoom:onVideoSubscribeStateChanged:info:state:reason}、rtcRoom:onAudioSubscribeStateChanged:info:state:reason:{@link #ByteRTCRoomDelegate#rtcRoom:onAudioSubscribeStateChanged:info:state:reason}。
当前房间中找不到订阅的音视频流导致订阅失败。SDK 会自动重试订阅,若仍订阅失败则建议你退出重试。 - ByteRTCWarningCodeSubscribeStreamFailed5xx → const ByteRTCWarningCode
-
@brief 订阅音视频流失败。通过以下回调通知: rtcRoom:onVideoSubscribeStateChanged:info:state:reason:{@link #ByteRTCRoomDelegate#rtcRoom:onVideoSubscribeStateChanged:info:state:reason}、rtcRoom:onAudioSubscribeStateChanged:info:state:reason:{@link #ByteRTCRoomDelegate#rtcRoom:onAudioSubscribeStateChanged:info:state:reason}。
当你订阅所在房间中的音视频流时,由于服务器错误导致订阅失败。SDK 会自动重试订阅。 - ByteRTCWarningCodeInvokeError → const ByteRTCWarningCode
-
@hidden currently not available @brief 函数调用顺序错误,当前代码中未使用。
- ByteRTCWarningCodeInvalidExpectMediaServerAddress → const ByteRTCWarningCode
-
@hidden for internal use only @brief 调度异常,服务器返回的媒体服务器地址不可用。
- ByteRTCWarningCodePublishStreamForbidden → const ByteRTCWarningCode
-
@brief 当调用
setUserVisibility:将自身可见性设置为 false 后,再尝试发布流会触发此警告。通过 rtcRoom:onVideoPublishStateChanged:info:state:reason:{@link #ByteRTCRoomDelegate#rtcRoom:onVideoPublishStateChanged:info:state:reason}、rtcRoom:onAudioPublishStateChanged:info:state:reason:{@link #ByteRTCRoomDelegate#rtcRoom:onAudioPublishStateChanged:info:state:reason} 回调。 - ByteRTCWarningCodeSendCustomMessage → const ByteRTCWarningCode
-
@brief 发送自定义广播消息失败,当前你未在房间中。
- ByteRTCWarningCodeCodeUserNotifyStop → const ByteRTCWarningCode
-
@brief 当房间内人数超过 500 人时,停止向房间内已有用户发送
rtcEngine:onUserJoined:elapsed:和rtcEngine:onUserLeave:reason:回调,并通过广播提示房间内所有用户。通过 rtcRoom:onRoomStateChanged:withUid:state:extraInfo:{@link #ByteRTCRoomDelegate#rtcRoom:onRoomStateChanged:withUid:state:extraInfo} 回调。 - ByteRTCWarningCodeUserInPublish → const ByteRTCWarningCode
-
@brief 用户已经在其他房间发布过流,或者用户正在发布 WTN 流。通过 rtcRoom:onVideoPublishStateChanged:info:state:reason:{@link #ByteRTCRoomDelegate#rtcRoom:onVideoPublishStateChanged:info:state:reason}、rtcRoom:onAudioPublishStateChanged:info:state:reason:{@link #ByteRTCRoomDelegate#rtcRoom:onAudioPublishStateChanged:info:state:reason} 回调,提示
kPublishStateChangeReasonNoPublishPermission回调。 - ByteRTCWarningCodeInEchoTestMode → const ByteRTCWarningCode
-
@brief 当前正在进行回路测试,该接口调用无效
- ByteRTCWarningCodeNoCameraPermission → const ByteRTCWarningCode
-
@brief 摄像头权限异常,当前应用没有获取摄像头权限
- ByteRTCWarningSetScreenAudioSourceTypeFailed → const ByteRTCWarningCode
-
@brief 不支持在 publishScreenAudio: 之后,通过
setScreenAudioSourceType设置屏幕音频采集类型 - ByteRTCWarningSetScreenAudioStreamIndexFailed → const ByteRTCWarningCode
-
@brief 不支持在 publishScreenAudio: 之后,通过
setScreenAudioStreamIndex设置屏幕音频混流类型 - ByteRTCWarningInvalidVoicePitch → const ByteRTCWarningCode
-
@brief 设置语音音高不合法
- ByteRTCWarningInvalidCallForExtAudio → const ByteRTCWarningCode
-
@brief 外部音频源新旧接口混用
- ByteRTCWarningCodeInvalidCanvasHandle → const ByteRTCWarningCode
-
@brief 指定的内部渲染画布句柄无效。
当你调用 setLocalVideoCanvas:{@link #ByteRTCEngine#setLocalVideoCanvas} 或 setRemoteVideoCanvas:withCanvas:{@link #ByteRTCEngine#setRemoteVideoCanvas:withCanvas} 时指定了无效的画布句柄,触发此回调。 - ByteRTCWarningCodeInvaildSamiAppkeyORToken → const ByteRTCWarningCode
-
@brief 音频技术 SDK 鉴权失效。联系技术支持人员。
- ByteRTCWarningCodeInvaildSamiResourcePath → const ByteRTCWarningCode
-
@brief 音频技术 资源加载失败。传入正确的 DAT 路径,或联系技术支持人员。
- ByteRTCWarningCodeLoadSamiLibraryFailed → const ByteRTCWarningCode
-
@brief 音频技术 库加载失败。使用正确的库,或联系技术支持人员。
- ByteRTCWarningCodeInvaildSamiEffectType → const ByteRTCWarningCode
-
@brief 音频技术 不支持此音效。联系技术支持人员。
- ByteRTCWarningCodeSubscribeStreamForbiden → const ByteRTCWarningCode
-
@hidden @deprecated since 3.45 and will be deleted in 3.51. @brief 自动订阅模式未关闭时,尝试开启手动订阅模式会触发此警告。
你需在进房前关闭自动订阅模式,再调用 subscribeStreamVideo:subscribe:{@link #ByteRTCRoom#subscribeStreamVideo:subscribe}/subscribeStreamAudio:subscribe:{@link #ByteRTCRoom#subscribeStreamAudio:subscribe} 方法手动订阅音视频流。 - ByteRTCWarningCodeRoomAlreadyExist → const ByteRTCWarningCode
-
@deprecated since 3.45 and will be deleted in 3.51. @brief 同样 roomid 的房间已经存在了
- ByteRTCWarningCodeNoMicrophonePermission → const ByteRTCWarningCode
-
@brief 已在 3.33 版本中废弃,使用 ByteRTCMediaDeviceError{@link #ByteRTCMediaDeviceError}.ByteRTCMediaDeviceErrorDeviceNoPermission 代替。
麦克风权限异常,当前应用没有获取麦克风权限。 @deprecated since 3.33 and will be deleted in 3.51, use ByteRTCMediaDeviceError{@link #ByteRTCMediaDeviceError}.ByteRTCMediaDeviceErrorDeviceNoPermission instead. - ByteRTCWarningCodeAudioDeviceManagerRecordingStartFail → const ByteRTCWarningCode
-
@brief 已在 3.33 版本中废弃,使用 ByteRTCMediaDeviceError{@link #ByteRTCMediaDeviceError}.ByteRTCMediaDeviceErrorDeviceFailure 代替。
音频采集设备启动失败。
启动音频采集设备失败,当前设备可能被其他应用占用。 @deprecated since 3.33 and will be deleted in 3.51, use ByteRTCMediaDeviceError{@link #ByteRTCMediaDeviceError}.ByteRTCMediaDeviceErrorDeviceFailure instead. - ByteRTCWarningCodeAudioDeviceManagerPlayoutStartFail → const ByteRTCWarningCode
-
@brief 已在 3.33 版本中废弃,使用 ByteRTCMediaDeviceError{@link #ByteRTCMediaDeviceError}.ByteRTCMediaDeviceErrorDeviceFailure 代替.
音频播放设备启动失败警告。
可能由于系统资源不足,或参数错误。 @deprecated since 3.33 and will be deleted in 3.51, use ByteRTCMediaDeviceError{@link #ByteRTCMediaDeviceError}.ByteRTCMediaDeviceErrorDeviceFailure instead. - ByteRTCWarningCodeNoRecordingDevice → const ByteRTCWarningCode
-
@brief 已在 3.33 版本中废弃,使用 ByteRTCMediaDeviceError{@link #ByteRTCMediaDeviceError}.ByteRTCMediaDeviceErrorDeviceNotFound 代替。
无可用音频采集设备。
启动音频采集设备失败,请插入可用的音频采集设备。 @deprecated since 3.33 and will be deleted in 3.51, use ByteRTCMediaDeviceError{@link #ByteRTCMediaDeviceError}.ByteRTCMediaDeviceErrorDeviceNotFound instead. - ByteRTCWarningCodeNoPlayoutDevice → const ByteRTCWarningCode
-
@brief 已在 3.33 版本中废弃,使用 ByteRTCMediaDeviceError{@link #ByteRTCMediaDeviceError}.ByteRTCMediaDeviceErrorDeviceNotFound 代替。
无可用音频播放设备。
启动音频播放设备失败,请插入可用的音频播放设备。 @deprecated since 3.33 and will be deleted in 3.51, use ByteRTCMediaDeviceError{@link #ByteRTCMediaDeviceError}.ByteRTCMediaDeviceErrorDeviceNotFound instead. - ByteRTCWarningCodeRecordingSilence → const ByteRTCWarningCode
-
@brief 已在 3.33 版本中废弃,使用 ByteRTCMediaDeviceWarning{@link #ByteRTCMediaDeviceWarning}.ByteRTCMediaDeviceWarningCaptureSilence 代替。
当前音频设备没有采集到有效的声音数据,请检查更换音频采集设备。 @deprecated since 3.33 and will be deleted in 3.51, use ByteRTCMediaDeviceWarning{@link #ByteRTCMediaDeviceWarning}.ByteRTCMediaDeviceWarningCaptureSilence instead. - ByteRTCWarningCodeMediaDeviceOperationDennied → const ByteRTCWarningCode
-
@brief 已在 3.33 版本中废弃,使用 ByteRTCMediaDeviceWarning{@link #ByteRTCMediaDeviceWarning}.ByteRTCMediaDeviceWarningOperationDenied 代替。
媒体设备误操作警告。
使用自定义采集时,不可调用内部采集开关,调用时触发此警告。 @deprecated since 3.33 and will be deleted in 3.51, use ByteRTCMediaDeviceWarning{@link #ByteRTCMediaDeviceWarning}.ByteRTCMediaDeviceWarningOperationDenied instead. - unknown → const ByteRTCWarningCode
Properties
- $value → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ByteRTCWarningCode> - A constant List of the values in this enum, in order of their declaration.