ByteRTSWarningCode enum
Values
- ByteRTSWarningCodeJoinRoomFailed → const ByteRTSWarningCode
-
@brief 进房失败。
初次进房或者由于网络状况不佳断网重连时,由于服务器错误导致进房失败。SDK 会自动重试进房。 - ByteRTSWarningCodePublishStreamFailed → const ByteRTSWarningCode
-
@brief 发布音视频流失败。
当你在所在房间中发布音视频流时,由于服务器错误导致发布失败。SDK 会自动重试发布。 - ByteRTSWarningCodeInvokeError → const ByteRTSWarningCode
-
@hidden currently not available @brief 函数调用顺序错误,当前代码中未使用。
- ByteRTSWarningCodeInvalidExpectMediaServerAddress → const ByteRTSWarningCode
-
@hidden for internal use only @brief 调度异常,服务器返回的媒体服务器地址不可用。
- ByteRTSWarningCodeSendCustomMessage → const ByteRTSWarningCode
-
@brief 发送自定义广播消息失败,当前你未在房间中。
- ByteRTSWarningCodeOldRoomBeenReplaced → const ByteRTSWarningCode
-
@brief 新生成的房间已经替换了同样 roomId 的旧房间
- ByteRTSWarningCodeRoomAlreadyExist → const ByteRTSWarningCode
-
@hidden @deprecated since 3.46 and will be deleted in 3.52. @brief 同样 roomid 的房间已经存在了
Properties
- $value → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ByteRTSWarningCode> - A constant List of the values in this enum, in order of their declaration.